#!/usr/bin/env bash
# Criticality: High
# Checks that the Live service is OK
set -e

PKG='ubicast-live'
error=false

# We check if the live package is installed
if dpkg -s ${PKG} &>/dev/null; then
    live_installed=true
else
    live_installed=false
fi

# If the live package is installed we check that it is OK
if ${live_installed}; then
        # For each live usage port (80 => HTTP, 443 => HTTPS, 1935 => RTMP)
        for port in 80 443 1935; do
                echo -n "Local port ${port}: "
                # We check that the port can be reached with a bash embedded tcp call
                if ! >/dev/tcp/127.0.0.1/${port} &>/dev/null; then
                        echo "KO"
                        error=true
                else
                        echo "OK"
                fi
        done

        # If one port was not reachable we exit with an error
        ${error} && exit 1
else
        # Code 2 is => not testable
        exit 2
fi

# Everything went fine
exit 0
